import * as process from 'process';
import * as yargs from 'yargs';
import { cli } from '../cli';
import chalk from 'chalk';
import { timeout } from "../utils/promises";

const rp = require('request-promise');
const fs = require('fs-extra');

export const command = 'create';
export const desc = 'Create a new Snips assistant';

const snipsfileSampleLocation = 'https://github.com/snipsco/demo-assistants/raw/master/Snipsfiles/Snipsfile.weather';

const fallbackSnipsfile = `
assistant_url: https://github.com/snipsco/demo-assistants/raw/master/assistants/weather.zip
skills:
  - url: https://github.com/snipsco/snips-skill-owm
    package_name: snipsowm
    class_name: SnipsOWM
    params:
        default_location: "Paris, fr"
        api_key: aaadcb52c143f85d59cd1e8da5d0eb1f
`;

export const handler = async (argv: yargs.Argv) => {
    cli.stream.loading('Creating new Snips assistant...');
    await timeout(1000);

    let snipsfile;
    try {
        snipsfile = await rp(snipsfileSampleLocation);
    } catch (e) {
        snipsfile = fallbackSnipsfile;
    }
    
    try {
        await fs.outputFile('Snipsfile', snipsfile.trim());
    } catch (e) {
        cli.stream.stopAndClear();
        cli.stream.error("Error creating assistant. Make sure you have write access to the current working directory", true);
        process.exit();
    };

    cli.stream.done();
    cli.stream.loading(`Loading sample assistant at ${process.cwd()}/Snipsfile...`);
    await timeout(1000);
    cli.stream.done();
    cli.stream.success('Snips assistant created');
    // cli.stream.println();
    cli.stream.hint(`You can now deploy the assistant to your device using ${chalk.blue('sam deploy')}`);
};

// TODO: review this with Charles
//
// export const handler = async (argv: yargs.Argv) => {
//     const ssh = new SSHService();
//     await ssh.connect().catch(e => cli.stream.error(e));

//     cli.stream.println('Creating new Snips assistant...');
//     await ssh.installSnipsPlatformDemo((output) => { cli.stream.print(output); })
//         .catch((e) => {
//             cli.stream.error('Failed to create Snips assistant: ' + e.message);
//             ssh.disconnect();
//             process.exit();
//         });

//     cli.stream.loading('Loading sample assistant...');
//     let snipsfile;
//     try {
//         // TODO - Add back
//         // snipsfile = await rp(snipsfileSampleLocation);
//         snipsfile = fallbackSnipsfile;
//     } catch (e) {
//         snipsfile = fallbackSnipsfile;
//     }

//     await ssh.copySnipsfile(snipsfile)
//         .catch((e) => {
//             cli.stream.error('Failed to load sample assistant: ' + e.message);
//             ssh.disconnect();
//             process.exit();
//         });

//     await ssh.runSnipsmanagerInstall((output) => { cli.stream.print(output); });
//     await ssh.runSnipsManager((output) => { cli.stream.print(output); });
//     ssh.disconnect();

//     cli.stream.success('Snips assistant created');
// };
