import * as process from 'process';
import * as yargs from 'yargs';
import chalk from 'chalk';
import cli from '../cli';
import { SSHService } from '../session/ssh';
import { timeout } from "../utils/promises";

exports.command = 'init';
exports.desc = 'Install Snips Platform components';

exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean'
    }
}

exports.handler = async (argv: yargs.Argv) => {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;
    
    cli.stream.loading('Installing Snips Platform components. List may take a few minutes...');
    
    const ssh = new SSHService();
    await ssh.connect().catch(e => {
        cli.stream.stop();
        cli.stream.error(e);
        process.exit();
    });

    await timeout(500);

    let didStopLoading = false;
    
    try {
        await ssh.installSnips((logMessage) => {
            if (verbose) {
                if (!didStopLoading) {
                    cli.stream.stop();
                    didStopLoading = true;
                }
                cli.stream.print(logMessage);
            }
        });
    } catch (e) {
        cli.stream.error('Failed to install platform: ' + e.stack);
        ssh.disconnect();
        process.exit();
    }

    ssh.disconnect();

    cli.stream.success('Successfully installed the Snips Platform');
    cli.stream.hint('You can now setup your microphone with ' + chalk.blue('sam setup microphone'));
};
